#!/usr/bin/env python
from setuptools import setup
setup(
    name='mfnbc',
    version='1.00',
    license='The MIT License (MIT)',
    author="Shawn",
    author_email='shawnzam@gmail.com',
    url='https://github.com/shawnzam/mfnbc',
    packages=['mfnbc'],
    install_requires=['nltk>=3.2'],
    keywords=['bayes'],
)
